// The Beep Library For Arduino - using a passive buzzer
// Changelog
// 20190622: NEW
#pragma once
#include "B4RDefines.h"
#include "EasyBuzzer.h"

namespace B4R {
	//~Version: 1.0
	//~shortname: EasyBuzzer
	class B4REasyBuzzer {
		private:
			EasyBuzzerClass* bn;
			uint8_t be[sizeof(EasyBuzzer)];
		public:

			/**
			*
			*Initializes the EasyBuzzer object
			*
			*/			
			void initialize();
			/**
			*
			*Beep continuously at the set frequency.
			*
			*/		
			void beepContinuously(UInt frequency);
			
			/**
			*			
			*Set the Pin to be used for the buzzer - default is Pin 4
			*/				
			void setPin(UInt pin);

			/**
			*			
			*Beep at a given frequency and for the specified number of times.
			*/				
			void beepFreqAndNoOfTimes(UInt frequency, UInt beeps);			
			
			/**
			*			
			*Beep at a given frequency, for the specified duration (in ms).
			*/	
			void singleBeep(UInt frequency, UInt duration);
			
			/**
			*Set On Duration (ms)
			*/	
			void setOnDuration(UInt duration);
			
			/**
			*Set Off Duration (ms)
			*/	
			void setOffDuration(UInt duration);	

			/**
			*Update function that keeps the library running.
			*Call it regularly from a timer
			*/	
			void update();	

			/**
			*			
			*Stop beeping.
			*/					
			void stopBeep();	

//			/**
//			*			
//			*Set Pause Duration
//			*/		
//			void setPauseDuration(UInt duration);	

			/**
			*			
			*Beep sequence at a given frequency.
			*sequence -> number of times to repeat the beep at frequency, onDuration, offDuration, beeps
			*beeps -> number of beeps in a single sequence
			*pauseDuration -> no-beep period between sequences
			*/		
			void beepSequence(UInt frequency, UInt onDuration, UInt offDuration, Byte beeps, UInt pauseDuration, UInt sequences);			
			
			
	};

}